# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.3](https://github.com/flying-sheep/xdot-rust/compare/v0.2.2...v0.2.3) - 2023-04-20

### Other
- Use PAT_GITHUB instead of GITHUB_TOKEN

## [0.2.2](https://github.com/flying-sheep/xdot-rust/compare/v0.2.1...v0.2.2) - 2023-04-20

### Other
- Add constructor and getters to FontCharacteristics (#18)
